==> frysk-0.2.1.tar.bz2: frysk-0.2.1/frysk-sys/frysk/sys/termios/Mode.java <==
// This file is part of the program FRYSK.
//
// Copyright 2007, Red Hat Inc.
//
// FRYSK is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// FRYSK is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with FRYSK; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
// 
// In addition, as a special exception, Red Hat, Inc. gives You the
// additional right to link the code of FRYSK with code not covered
// under the GNU General Public License ("Non-GPL Code") and to
// distribute linked combinations including the two, subject to the
// limitations in this paragraph. Non-GPL Code permitted under this
// exception must only link to the code of FRYSK through those well
// defined interfaces identified in the file named EXCEPTION found in
// the source code files (the "Approved Interfaces"). The files of
// Non-GPL Code may instantiate templates or use macros or inline
// functions from the Approved Interfaces without causing the
// resulting work to be covered by the GNU General Public
// License. Only Red Hat, Inc. may make changes or additions to the
// list of Approved Interfaces. You must obey the GNU General Public
// License in all respects for all of the FRYSK code and other code
// used in conjunction with FRYSK except the Non-GPL Code covered by
// this exception. If you modify this file, you may extend this
// exception to your version of the file, but you are not obligated to
// do so. If you do not wish to provide this exception without
// modification, you must delete this exception statement from your
// version and license this file solely under the GPL without
// exception.

package frysk.sys.termios;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.LinkedList;
import java.util.List;
import java.util.Iterator;

/**
 * Termios modes.
 */
abstract class Mode
{
    protected Mode ()
    {
	throw new RuntimeException ("should not be creating an empty mode");
    }
    protected final String on;
    protected Mode (String on)
    {
	this.on = on;
    }
    public String toString ()
    {
	return on;
    }
    public String toString (Termios termios)
    {
	if (get (termios))
	    return on;
	else
	    return "-" + on;
    }
    abstract Termios set (Termios termios, boolean on);
    abstract boolean get (Termios termios);

    /**
     * Return a linked list of the objects static Fields.
     */
    static final List getStaticFields (Class c)
    {
	List staticFields = new LinkedList ();
	Field[] fields = c.getFields ();
	for (int i = 0; i < fields.length; i++) {
	    Field field = fields[i];
	    if (!Modifier.isStatic (field.getModifiers ()))
		continue;
	    staticFields.add (field);
	}
	return staticFields;
    }

    /**
     * Return a linked list of the classes static members.
     */
    static final List getStaticMembers (Class c)
    {
	List members = new LinkedList ();
	try {
	    for (Iterator i = getStaticFields (c).iterator ();
		 i.hasNext (); ) {
		Field field = (Field)i.next ();
		Object o = field.get (null);
		members.add (o);
	    }
	}
	catch (java.lang.IllegalAccessException e) {
	    throw new RuntimeException (e);
	}
	return members;
    }
}

==> frysk-0.4.tar.bz2: frysk-0.4/frysk-sys/frysk/sys/termios/Mode.java <==
// This file is part of the program FRYSK.
//
// Copyright 2007, 2008, Red Hat Inc.
//
// FRYSK is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// FRYSK is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with FRYSK; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
// 
// In addition, as a special exception, Red Hat, Inc. gives You the
// additional right to link the code of FRYSK with code not covered
// under the GNU General Public License ("Non-GPL Code") and to
// distribute linked combinations including the two, subject to the
// limitations in this paragraph. Non-GPL Code permitted under this
// exception must only link to the code of FRYSK through those well
// defined interfaces identified in the file named EXCEPTION found in
// the source code files (the "Approved Interfaces"). The files of
// Non-GPL Code may instantiate templates or use macros or inline
// functions from the Approved Interfaces without causing the
// resulting work to be covered by the GNU General Public
// License. Only Red Hat, Inc. may make changes or additions to the
// list of Approved Interfaces. You must obey the GNU General Public
// License in all respects for all of the FRYSK code and other code
// used in conjunction with FRYSK except the Non-GPL Code covered by
// this exception. If you modify this file, you may extend this
// exception to your version of the file, but you are not obligated to
// do so. If you do not wish to provide this exception without
// modification, you must delete this exception statement from your
// version and license this file solely under the GPL without
// exception.

package frysk.sys.termios;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.util.LinkedList;
import java.util.List;
import java.util.Iterator;

/**
 * Termios modes.
 */
abstract class Mode {
    protected Mode() {
	throw new RuntimeException ("should not be creating an empty mode");
    }
    protected final String on;
    protected Mode(String on) {
	this.on = on;
    }
    public String toString() {
	return on;
    }
    public String toString(Termios termios) {
	if (termios.get(this))
	    return on;
	else
	    return "-" + on;
    }
    abstract void set(long termios, boolean on);
    abstract boolean get(long termios);

    /**
     * Return a linked list of the objects static Fields.
     */
    static final List getStaticFields(Class c) {
	List staticFields = new LinkedList ();
	Field[] fields = c.getFields ();
	for (int i = 0; i < fields.length; i++) {
	    Field field = fields[i];
	    if (!Modifier.isStatic (field.getModifiers ()))
		continue;
	    staticFields.add (field);
	}
	return staticFields;
    }

    /**
     * Return a linked list of the classes static members.
     */
    static final List getStaticMembers(Class c) {
	List members = new LinkedList ();
	try {
	    for (Iterator i = getStaticFields (c).iterator ();
		 i.hasNext (); ) {
		Field field = (Field)i.next ();
		Object o = field.get (null);
		members.add (o);
	    }
	} catch (java.lang.IllegalAccessException e) {
	    throw new RuntimeException (e);
	}
	return members;
    }
}
